@@ -27,9 +27,8 @@ Q_DECLARE_METATYPE(Akonadi::NotificationSubscriber)
 
 MonitorsWidget::MonitorsWidget(QWidget *parent)
     : QWidget(parent)
+    , mModel(new MonitorsModel(this))
 {
-    mModel = new MonitorsModel(this);
-
     auto layout = new QHBoxLayout(this);
 
     mTreeView = new QTreeView(this);
@@ -67,7 +66,8 @@ MonitorsWidget::~MonitorsWidget()
 }
 
 // Specialization of function template from utils.h
-template<> QString toString(const QSet<Akonadi::Monitor::Type> &set)
+template<>
+QString toString(const QSet<Akonadi::Monitor::Type> &set)
 {
     QStringList rv;
     for (const auto &v : set) {
